@@ -1,11 +1,11 @@
 /*  File src/MHproposals_DynMLE_block.h in package tergm, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
+ *  of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
+ *  https://statnet.org/attribution
  *
- *  Copyright 2008-2018 Statnet Commons
+ *  Copyright 2008-2019 Statnet Commons
  */
 #ifndef MHproposals_DynMLE_H
 #define MHproposals_DynMLE_H
@@ -15,8 +15,8 @@
 #include "model.h"
 #include "MHproposal.h"
 
-void MH_FormationMLEblockdiag(MHproposal *MHp, Network *nwp);
-void MH_FormationMLEblockdiagTNT(MHproposal *MHp, Network *nwp);
+void MH_FormationMLEblockdiag(MHProposal *MHp, Network *nwp);
+void MH_FormationMLEblockdiagTNT(MHProposal *MHp, Network *nwp);
 
 #endif 
 
