@@ -1,11 +1,11 @@
 /*  File src/changestats_duration.c in package tergm, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
+ *  of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
+ *  https://statnet.org/attribution
  *
- *  Copyright 2008-2018 Statnet Commons
+ *  Copyright 2008-2019 Statnet Commons
  */
 #include "changestats_duration.h"
 
@@ -159,7 +159,6 @@ D_CHANGESTAT_FN(d_edges_ageinterval_mon){
 }
 
 S_CHANGESTAT_FN(s_edges_ageinterval_mon){
-  int i;
   ZERO_ALL_CHANGESTATS(i);
   for (Edge k=1; k <= N_EDGES; k++){
     Vertex tail, head;
@@ -585,12 +584,11 @@ D_CHANGESTAT_FN(d_degree_mean_age_mon){
 
 
 S_CHANGESTAT_FN(s_degree_mean_age_mon){
-  int i;
   Vertex *id=IN_DEG, *od=OUT_DEG;
   double zeroval = INPUT_PARAM[0];
   int transform = INPUT_PARAM[1]; // Transformation code.
 
-  ZERO_ALL_CHANGESTATS(i);
+  ZERO_ALL_CHANGESTATS();
 
   for(unsigned int j = 0; j < N_CHANGE_STATS; j++){
     Vertex deg = INPUT_PARAM[j+2];
@@ -791,7 +789,6 @@ D_CHANGESTAT_FN(d_degree_by_attr_mean_age_mon){
 }
 
 S_CHANGESTAT_FN(s_degree_by_attr_mean_age_mon){
-  int i;
   Vertex *id=IN_DEG, *od=OUT_DEG;
   double zeroval = INPUT_PARAM[0];
   int transform = INPUT_PARAM[1]; // Transformation code.
@@ -1015,7 +1012,6 @@ D_CHANGESTAT_FN(d_degrange_mean_age_mon){
 
 
 S_CHANGESTAT_FN(s_degrange_mean_age_mon){
-  int i;
   Vertex *id=IN_DEG, *od=OUT_DEG;
   double zeroval = INPUT_PARAM[0];
   int transform = INPUT_PARAM[1]; // Transformation code.
@@ -1246,7 +1242,6 @@ D_CHANGESTAT_FN(d_degrange_by_attr_mean_age_mon){
 }
 
 S_CHANGESTAT_FN(s_degrange_by_attr_mean_age_mon){
-  int i;
   Vertex *id=IN_DEG, *od=OUT_DEG;
   double zeroval = INPUT_PARAM[0];
   int transform = INPUT_PARAM[1]; // Transformation code.
