@@ -1,19 +1,25 @@
 #  File tests/dynamic_MLE.R in package tergm, part of the Statnet suite
-#  of packages for network analysis, http://statnet.org .
+#  of packages for network analysis, https://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) at
-#  http://statnet.org/attribution
+#  https://statnet.org/attribution
 #
-#  Copyright 2008-2018 Statnet Commons
+#  Copyright 2008-2019 Statnet Commons
 #######################################################################
 library(tergm)
+options(tergm.eval.loglik=FALSE)
 
 tolerance<-0.05
 n<-10
 m<-6
 theta<--1.5
 
+z.error <- function(truth, fit){
+  if(truth==coef(fit)) 0 # Infinite case
+  else abs(truth-coef(fit))/sqrt(diag(vcov(fit)))
+}
+
 logit<-function(p) log(p/(1-p))
 
 form.mle<-function(y0,y1){
@@ -31,28 +37,28 @@ if(bip){ # Extreme theta creates networks with too few ties to properly test.
   
 y0<-network.initialize(n,dir=dir,bipartite=bip)
 set.seed(321)
-y0<-standardize.network(simulate(y0~edges, coef=theta, control=control.simulate(MCMC.burnin=n^2*2)))
+y0<-simulate(y0~edges, coef=theta, control=control.simulate(MCMC.burnin=n^2*2))
 
 cat("Complete data:\n")
 
 set.seed(123)
-y1<-standardize.network(simulate(y0~edges, coef=theta, control=control.simulate(MCMC.burnin=n^2*2)))
+y1<-simulate(y0~edges, coef=theta, control=control.simulate(MCMC.burnin=n^2*2))
 
 # Force CMPLE
 set.seed(543)
 fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMPLE", times=c(1,2), eval.loglik=FALSE)
 
 stopifnot(fit$estimate=="CMPLE", fit$formation.fit$estimate=="MPLE", fit$dissolution.fit$estimate=="MPLE")
-stopifnot(all.equal(form.mle(y0,y1), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
-stopifnot(all.equal(diss.mle(y0,y1), coef(fit$dissolution.fit), tolerance=tolerance, check.attributes=FALSE))
+stopifnot(z.error(form.mle(y0,y1), fit$formation.fit) <= tolerance)
+stopifnot(z.error(diss.mle(y0,y1), fit$dissolution.fit) <= tolerance)
 
 # Autodetected CMPLE
 set.seed(543)
 fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMLE", times=c(1,2), eval.loglik=FALSE)
 
 stopifnot(fit$estimate=="CMLE", is.null(fit$formation.fit$sample), is.null(fit$dissolution.fit$sample))
-stopifnot(all.equal(form.mle(y0,y1), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
-stopifnot(all.equal(diss.mle(y0,y1), coef(fit$dissolution.fit), tolerance=tolerance, check.attributes=FALSE))
+stopifnot(z.error(form.mle(y0,y1), fit$formation.fit) <= tolerance)
+stopifnot(z.error(diss.mle(y0,y1), fit$dissolution.fit) <= tolerance)
 
 # Force CMLE
 for(prop.weight in prop.weights){
@@ -61,8 +67,8 @@ set.seed(543)
 fit<-stergm(list(y0,y1), formation=~edges, dissolution=~edges, estimate="CMLE", control=control.stergm(CMLE.control=control.ergm(force.main=TRUE, MCMC.prop.weights=prop.weight)), times=c(1,2), eval.loglik=FALSE)
 
 stopifnot(fit$estimate=="CMLE", fit$formation.fit$estimate=="MLE", fit$dissolution.fit$estimate=="MLE")
-stopifnot(all.equal(form.mle(y0,y1), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
-stopifnot(all.equal(diss.mle(y0,y1), coef(fit$dissolution.fit), tolerance=tolerance, check.attributes=FALSE))
+stopifnot(z.error(form.mle(y0,y1), fit$formation.fit) <= tolerance)
+stopifnot(z.error(diss.mle(y0,y1), fit$dissolution.fit) <= tolerance)
 }
 
 cat("Missing data:\n")
@@ -78,16 +84,16 @@ set.seed(765)
 fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMPLE", times=c(1,2), eval.loglik=FALSE)
 
 stopifnot(fit$estimate=="CMPLE", fit$formation.fit$estimate=="MPLE", fit$dissolution.fit$estimate=="MPLE")
-stopifnot(all.equal(form.mle(y0,y1m), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
-stopifnot(all.equal(diss.mle(y0,y1m), coef(fit$dissolution.fit), tolerance=tolerance, check.attributes=FALSE))
+stopifnot(z.error(form.mle(y0,y1m), fit$formation.fit) <= tolerance)
+stopifnot(z.error(diss.mle(y0,y1m), fit$dissolution.fit) <= tolerance)
 
 # Autodetected CMPLE
 set.seed(765)
 fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMLE", times=c(1,2), eval.loglik=FALSE)
 
 stopifnot(fit$estimate=="CMLE", is.null(fit$formation.fit$sample), is.null(fit$dissolution.fit$sample))
-stopifnot(all.equal(form.mle(y0,y1m), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
-stopifnot(all.equal(diss.mle(y0,y1m), coef(fit$dissolution.fit), tolerance=tolerance, check.attributes=FALSE))
+stopifnot(z.error(form.mle(y0,y1m), fit$formation.fit) <= tolerance)
+stopifnot(z.error(diss.mle(y0,y1m), fit$dissolution.fit) <= tolerance)
 
 # Force CMLE
 for(prop.weight in prop.weights){
@@ -96,8 +102,8 @@ set.seed(234)
 fit<-stergm(list(y0,y1m), formation=~edges, dissolution=~edges, estimate="CMLE", control=control.stergm(CMLE.control=control.ergm(force.main=TRUE, MCMC.prop.weights=prop.weight)), times=c(1,2), eval.loglik=FALSE)
 
 stopifnot(fit$estimate=="CMLE", fit$formation.fit$estimate=="MLE", fit$dissolution.fit$estimate=="MLE")
-stopifnot(all.equal(form.mle(y0,y1m), coef(fit$formation.fit), tolerance=tolerance, check.attributes=FALSE))
-stopifnot(all.equal(diss.mle(y0,y1m), coef(fit$dissolution.fit), tolerance=tolerance, check.attributes=FALSE))
+stopifnot(z.error(form.mle(y0,y1m), fit$formation.fit) <= tolerance)
+stopifnot(z.error(diss.mle(y0,y1m), fit$dissolution.fit) <= tolerance)
 }
 }
 
